@@ -3,24 +3,24 @@ data(sanction)
 
 # Fit the statistical model
 
-z.out <- zelig(num ~ target + coop, model = "negbinom", data = sanction)
+z <- zelig(num ~ target + coop, model = "negbinom", data = sanction)
 
 # Set explanatory variables (in this case, nothing is explicitly set)
 
-x.out <- setx(z.out)
+x <- setx(z)
 
 # Simulate Quantities of Interest
 
-s.out <- sim(z.out, x = x.out)
+s <- sim(z, x)
 
 # Summarize the statistical model
 
-summary(z.out)
+summary(z)
 
 # Summarize the simulated quantities of interest
 
-summary (s,out)
+summary (s)
 
 # Plot the results
 
-plot(s.out)
+plot(s)
