@@ -22,10 +22,9 @@ user.prompt()
 plot.ci(s.out, xlab = "Age in Years",
         ylab = "Predicted Probability of Voting",
         main = "Effect of Education and Age on Voting Behavior")
-user.prompt()
-legend(45, 0.55, legend = c("College Education (16 years)",
-       "High School Education (12 years)"), col = c("blue","red"), 
-       lty = c("solid"))
+
+text(x=50,y=.95,labels="College Education (16 years)",cex=0.6)
+text(x=60,y=.8,labels="High School Education (12 years)",cex=0.6)
 
 
 
